from IPython.core.display import display, HTML
from ..isa import ISAMagic
from ..ml import MLMagic
from .generic import Generic


class Jupyter(Generic):
    def __init__(self, *args, **kargs):
        super().__init__(*args, **kargs)

    def show(self, dataframe, limit=100):
        display(HTML(dataframe.limit(limit).toPandas().to_html()))

    def command_aux(self, ISAContext):
        ISAMagic(ISAContext)

    def command_ml(self, MLContext):
        MLMagic(MLContext)


from enum import Enum

class Interfaces(Enum):
    GENERIC = 0
    ZEPPELIN = 1
    JUPYTER = 2

class Interface:

    @staticmethod
    def get_interface(interface, *args, **kargs):

        if (interface is Interfaces.ZEPPELIN):
            from .zeppelin import Zeppelin
            return Zeppelin(*args, **kargs)

        if (interface is Interfaces.JUPYTER):

            from .jupyter import Jupyter
            return Jupyter(*args, **kargs)
        else:

            from .generic import Generic
            return Generic(*args, **kargs)

    def get_interfaces(self):
        return Interfaces


import os

class Generic:
    def __init__(self,*args,**kargs):
        pass

    def get_user(self):
        return dict(user = os.environ.get('DORA_USER'))

    def show(self, dataframe):
        dataframe.show()

    def command_aux(self, ISAContext):
        pass

    def command_ml(self, MLContext):
        pass